# GitOPENLib

This library contains Python code snippets THAT I often use.

If you need it, you can install it with the `pip install gitopenlib` command.

**May goodness live on forever.**

Powered by GitOPEN.

